@@ -6,9 +6,13 @@ from itertools import chain
 from django import forms
 from django.forms.formsets import TOTAL_FORM_COUNT
 from django.forms.models import fields_for_model
-from django.utils.translation import ungettext
+from django.utils.translation import ngettext
 
-from modeltranslation_rosetta.settings import DEFAULT_FROM_LANG, DEFAULT_TO_LANG, LANGUAGES
+from modeltranslation_rosetta.settings import (
+    DEFAULT_FROM_LANG,
+    DEFAULT_TO_LANG,
+    LANGUAGES,
+)
 from .import_translation import parse_po, parse_xlsx, parse_xml
 from .utils import build_localized_fieldname
 from .utils import get_model, build_model_name, get_models
@@ -17,66 +21,69 @@ from .utils import get_model, build_model_name, get_models
 class ImportTranslationForm(forms.Form):
     file = forms.FileField()
 
-    from_lang = forms.ChoiceField(choices=[('', 'Auto detect (only xlsx)')] + LANGUAGES,
-                                  initial=DEFAULT_FROM_LANG,
-                                  required=False)
-    to_lang = forms.ChoiceField(choices=[('', 'Auto detect (only xlsx)')] + LANGUAGES,
-                                initial=DEFAULT_TO_LANG, required=False)
+    from_lang = forms.ChoiceField(
+        choices=[("", "Auto detect (only xlsx)")] + LANGUAGES,
+        initial=DEFAULT_FROM_LANG,
+        required=False,
+    )
+    to_lang = forms.ChoiceField(
+        choices=[("", "Auto detect (only xlsx)")] + LANGUAGES,
+        initial=DEFAULT_TO_LANG,
+        required=False,
+    )
 
     def clean(self):
         data = dict(self.cleaned_data)
-        _file = data['file']
-        from_lang = data['from_lang']
-        to_lang = data['to_lang']
+        _file = data["file"]
+        from_lang = data["from_lang"]
+        to_lang = data["to_lang"]
         if all([from_lang, to_lang]) and from_lang == to_lang:
-            self.add_error('from_lang', "Lang must be not equal")
-            self.add_error('to_lang', "Lang must be not equal")
+            self.add_error("from_lang", "Lang must be not equal")
+            self.add_error("to_lang", "Lang must be not equal")
             return
-        if _file.name.lower().endswith('.po'):
-            file_format = 'po'
-            for f in ['to_lang', 'from_lang']:
+        if _file.name.lower().endswith(".po"):
+            file_format = "po"
+            for f in ["to_lang", "from_lang"]:
                 if not data[f]:
                     self.add_error(f, "No possible detect, must be define lang")
                     return
             try:
-                dataset = parse_po(_file,
-                                   from_lang=from_lang,
-                                   to_lang=to_lang)
+                dataset = parse_po(_file, from_lang=from_lang, to_lang=to_lang)
             except Exception as e:
-                self.add_error('file', "Invalid po file: %s" % e)
+                self.add_error("file", "Invalid po file: %s" % e)
                 return
 
-        elif _file.name.lower().endswith('.xlsx'):
-            file_format = 'xlsx'
+        elif _file.name.lower().endswith(".xlsx"):
+            file_format = "xlsx"
             try:
                 dataset = parse_xlsx(_file)
             except Exception as e:
-                self.add_error('file', "Invalid xlsx file: %s" % e)
+                self.add_error("file", "Invalid xlsx file: %s" % e)
                 return
-        elif _file.name.lower().endswith('.xml'):
-            file_format = 'xml'
-            for f in ['to_lang', 'from_lang']:
+        elif _file.name.lower().endswith(".xml"):
+            file_format = "xml"
+            for f in ["to_lang", "from_lang"]:
                 if not data[f]:
                     self.add_error(f, "No possible detect, must be define lang")
                     return
             try:
                 dataset = parse_xml(_file, from_lang=from_lang, to_lang=to_lang)
             except Exception as e:
-                self.add_error('file', "Invalid xml file: %s" % e)
+                self.add_error("file", "Invalid xml file: %s" % e)
                 return
 
         else:
-            self.add_error('file', "Invalid file extension. Must be .po or .xlsx")
+            self.add_error("file", "Invalid file extension. Must be .po or .xlsx")
             return
 
-        if file_format == 'xlsx':
+        if file_format == "xlsx":
             try:
                 row = dataset.__next__()
             except StopIteration:
-                self.add_error('file', "No rows!")
+                self.add_error("file", "No rows!")
                 return
 
-            for f in ['to_lang', 'from_lang']:
+            for f in ["to_lang", "from_lang"]:
                 _lang = data[f]
                 if not _lang:
                     _lang = row[f]
@@ -88,46 +95,53 @@ class ImportTranslationForm(forms.Form):
             # Restore iterator
             dataset = chain([row], dataset)
 
-        data['dataset'] = dataset
+        data["dataset"] = dataset
         return data
 
 
 class ExportTranslationForm(forms.Form):
     translation_models = forms.MultipleChoiceField(
-        choices=[],
-        widget=forms.CheckboxSelectMultiple,
-        required=False
+        choices=[], widget=forms.CheckboxSelectMultiple, required=False
+    )
+    format = forms.ChoiceField(
+        choices=[
+            ("po", ".PO file"),
+            ("xlsx", ".XLSX file"),
+            ("xml", ".XML file"),
+            ("xml_merged", ".XML merged"),
+        ]
     )
-    format = forms.ChoiceField(choices=[('po', '.PO file'), ('xlsx', '.XLSX file'), ('xml', '.XML file'), ('xml_merged', '.XML merged')])
     from_lang = forms.ChoiceField(choices=LANGUAGES, initial=DEFAULT_FROM_LANG)
     to_lang = forms.ChoiceField(choices=LANGUAGES, initial=DEFAULT_TO_LANG)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        choices = [(key, f"{info['meta'].verbose_name} [{key}]") for key, info in
-                   get_models().items()]
-        self.fields['translation_models'].choices = choices
+        choices = [
+            (key, f"{info['meta'].verbose_name} [{key}]")
+            for key, info in get_models().items()
+        ]
+        self.fields["translation_models"].choices = choices
 
     def clean(self):
         data = dict(self.cleaned_data)
-        if data['from_lang'] == data['to_lang']:
-            self.add_error("to_lang", 'from_lang equals to_lang')
-            self.add_error("from_lang", 'from_lang equals to_lang')
+        if data["from_lang"] == data["to_lang"]:
+            self.add_error("to_lang", "from_lang equals to_lang")
+            self.add_error("from_lang", "from_lang equals to_lang")
         return data
 
 
 class FieldFormSet(forms.BaseModelFormSet):
     def __init__(self, *args, **kwargs):
-        self._only_fields = kwargs.pop('fields', None)
-        self.from_lang = kwargs.pop('from_lang')
-        self.to_lang = kwargs.pop('to_lang')
+        self._only_fields = kwargs.pop("fields", None)
+        self.from_lang = kwargs.pop("from_lang")
+        self.to_lang = kwargs.pop("to_lang")
         super(FieldFormSet, self).__init__(*args, **kwargs)
 
     def get_form_kwargs(self, index):
         kwargs = super().get_form_kwargs(index)
-        kwargs['fields'] = self._only_fields
-        kwargs['from_lang'] = self.from_lang
-        kwargs['to_lang'] = self.to_lang
+        kwargs["fields"] = self._only_fields
+        kwargs["from_lang"] = self.from_lang
+        kwargs["to_lang"] = self.to_lang
         return kwargs
 
     def _construct_form(self, i, **kwargs):
@@ -176,21 +190,35 @@ class FieldFormSet(forms.BaseModelFormSet):
             self._errors.append(form.errors)
         try:
             if (
-                    (self.validate_max
-                     and self.total_form_count() - len(self.deleted_forms) > self.max_num)
-                    or self.management_form.cleaned_data[TOTAL_FORM_COUNT] > self.absolute_max):
-                raise forms.ValidationError(
-                    ungettext("Please submit %d or fewer forms.",
-                              "Please submit %d or fewer forms.", self.max_num
-                              ) % self.max_num,
-                    code='too_many_forms',
+                (
+                    self.validate_max
+                    and self.total_form_count() - len(self.deleted_forms) > self.max_num
                 )
-            if (self.validate_min
-                    and self.total_form_count() - len(self.deleted_forms) < self.min_num):
+                or self.management_form.cleaned_data[TOTAL_FORM_COUNT]
+                > self.absolute_max
+            ):
                 raise forms.ValidationError(
-                    ungettext("Please submit %d or more forms.",
-                              "Please submit %d or more forms.", self.min_num) % self.min_num,
-                    code='too_few_forms')
+                    ngettext(
+                        "Please submit %d or fewer forms.",
+                        "Please submit %d or fewer forms.",
+                        self.max_num,
+                    )
+                    % self.max_num,
+                    code="too_many_forms",
+                )
+            if (
+                self.validate_min
+                and self.total_form_count() - len(self.deleted_forms) < self.min_num
+            ):
+                raise forms.ValidationError(
+                    ngettext(
+                        "Please submit %d or more forms.",
+                        "Please submit %d or more forms.",
+                        self.min_num,
+                    )
+                    % self.min_num,
+                    code="too_few_forms",
+                )
             # Give self.clean() a chance to do cross-form validation.
             self.clean()
         except forms.ValidationError as e:
@@ -199,20 +227,23 @@ class FieldFormSet(forms.BaseModelFormSet):
 
 class FieldForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
-        self._only_fields = kwargs.pop('fields', None)
-        self._from_lang = kwargs.pop('from_lang')
-        self._to_lang = kwargs.pop('to_lang')
+        self._only_fields = kwargs.pop("fields", None)
+        self._from_lang = kwargs.pop("from_lang")
+        self._to_lang = kwargs.pop("to_lang")
         super(FieldForm, self).__init__(*args, **kwargs)
         self.model_info = get_model(build_model_name(self.instance))
         self.build_fields()
 
     def get_translated_fields(self):
-        opts = self.model_info['opts']
+        opts = self.model_info["opts"]
         fields = [
-            [field_name, (
-                build_localized_fieldname(field_name, self._from_lang),
-                build_localized_fieldname(field_name, self._to_lang)
-            )]
+            [
+                field_name,
+                (
+                    build_localized_fieldname(field_name, self._from_lang),
+                    build_localized_fieldname(field_name, self._to_lang),
+                ),
+            ]
             for field_name in sorted(opts.fields.keys())
             if not self._only_fields or field_name in self._only_fields
         ]
@@ -225,7 +256,7 @@ class FieldForm(forms.ModelForm):
             fields.extend(translated_fields)
 
         self._meta.fields += fields
-        self.fields.update(fields_for_model(self.model_info['model'], fields))
+        self.fields.update(fields_for_model(self.model_info["model"], fields))
 
     def group_fields(self):
         fields = []
