@@ -8,6 +8,6 @@ register = Library()
 
 @register.simple_tag(takes_context=True)
 def get_params(context, field, value):
-    dict_ = context['request'].GET.copy()
+    dict_ = context["request"].GET.copy()
     dict_[field] = value
     return dict_.urlencode()
